Written for Python 3.6+

Installation:
sudo pip install Dpowers

Further dependencies:
sudo apt install xdotool wmctrl zenity yad xsel xclip x11-xserver-utils
 python3-tk pywand


Start your Script e.g. with the following lines:

from Dpowers import *

Icon().start()





Documentation and/or more examples will be added later. I tested everything
 on my device, but it might still contain some bugs.
